# Copyright (c) 2000-2014, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%bcond_without maven

%define section free

Name:           xmlrpc
Version:        3.1.3
Release:        5%{?dist}
Epoch:          0
Summary:        Java XML-RPC implementation
License:        ASL 2.0
Group:          Development/Java
URL:            http://ws.apache.org/xmlrpc/
Source0:        http://www.apache.org/dist/ws/xmlrpc/sources/apache-xmlrpc-3.1.3-src.tar.gz
Source1:        %{name}-settings.xml
Source2:        %{name}-jpp-depmap.xml
Source3:        %{name}-build.xml
Source4:        %{name}-client-build.xml
Source5:        %{name}-common-build.xml
Source6:        %{name}-server-build.xml
Source7:        %{name}-tests-build.xml
Patch0:         xmlrpc-pom_xml.patch
Patch1:         xmlrpc-tests-pom_xml.patch
Patch2:         xmlrpc-site_xml.patch
Requires:       apache-commons-codec
Requires:       apache-commons-httpclient
Requires:       apache-commons-logging
Requires:       servlet_2_5_api
Requires:       ws-commons-util
BuildRequires:  jpackage-utils >= 0:1.7.5
BuildRequires:  java-devel >= 0:1.6.0
BuildRequires:  ant >= 0:1.7.1
BuildRequires:  junit
BuildRequires:  apache-commons-codec
BuildRequires:  apache-commons-httpclient
BuildRequires:  apache-commons-logging
BuildRequires:  servlet_2_5_api
BuildRequires:  ws-commons-util
%if %with maven
BuildRequires:  maven2
BuildRequires:  maven-assembly-plugin
BuildRequires:  maven-changes-plugin
BuildRequires:  maven-compiler-plugin
BuildRequires:  maven-eclipse-plugin
BuildRequires:  maven-install-plugin
BuildRequires:  maven-jar-plugin
BuildRequires:  maven-javadoc-plugin
BuildRequires:  maven-resources-plugin
BuildRequires:  velocity15
BuildRequires:  maven-site-plugin
BuildRequires:  maven-source-plugin
BuildRequires:  maven-surefire-plugin
BuildRequires:  maven-surefire-provider-junit3
BuildRequires:  maven-skins
BuildRequires:  maven-release
BuildRequires:  apache-commons-parent
BuildRequires:  apache-rat
%endif
Buildarch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
Apache XML-RPC is a Java implementation of XML-RPC, a popular protocol
that uses XML over HTTP to implement remote procedure calls.
Apache XML-RPC was previously known as Helma XML-RPC. If you have code
using the Helma library, all you should have to do is change the import
statements in your code from helma.xmlrpc.* to org.apache.xmlrpc.*.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation
Requires:       jpackage-utils

%description javadoc
%{summary}.

%if %with maven
%package manual
Summary:        Documents for %{name}
Group:          Development/Documentation

%description manual
%{summary}.
%endif

%prep
%setup -q -n apache-%{name}-%{version}-src
%patch0 -b .sav0
cp -p %{SOURCE1} settings.xml
cp -p %{SOURCE3} build.xml
cp -p %{SOURCE4} client/build.xml
cp -p %{SOURCE5} common/build.xml
cp -p %{SOURCE6} server/build.xml

perl -pi -e 's/\r$//g' LICENSE.txt

%build
%if %with maven
%{_bindir}/mvn-jpp \
        -Dmaven2.jpp.depmap.file=%{SOURCE2} \
        -Dmaven.repo.local=`pwd`/.m2/repository \
        -Dmaven.test.failure.ignore=true \
        install javadoc:aggregate site:site

%else
pushd common
export CLASSPATH=`%{_bindir}/build-classpath junit ws-commons-java5 ws-commons-util jaxme/jaxmeapi`
export OPT_JAR_LIST=:
%{ant} -Dbuild.sysclasspath=only jar javadoc
popd

pushd client
export CLASSPATH=$(build-classpath junit ws-commons-java5 ws-commons-util commons-httpclient)
CLASSPATH=$CLASSPATH:../common/target/%{name}-common-%{version}.jar
%{ant} -Dbuild.sysclasspath=only jar javadoc
popd

pushd server
export CLASSPATH=$(build-classpath junit commons-logging ws-commons-java5 ws-commons-util servlet_2_4_api)
CLASSPATH=$CLASSPATH:../common/target/%{name}-common-%{version}.jar
%{ant} -Dbuild.sysclasspath=only jar javadoc
popd

%endif
mkdir -p temp
pushd temp
%{jar} xf ../server/target/%{name}-server-%{version}.jar
%{jar} xf ../client/target/%{name}-client-%{version}.jar
%{jar} xf ../common/target/%{name}-common-%{version}.jar
%{__sed} -i -e "s|-common||g" META-INF/MANIFEST.MF
%{jar} cmf META-INF/MANIFEST.MF ../%{name}-%{version}.jar *
popd

%install
rm -rf $RPM_BUILD_ROOT

# jars
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}/%{name}
install -m 644 xmlrpc-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/xmlrpc-%{version}.jar
install -m 644 common/target/xmlrpc-common-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/xmlrpc-common-%{version}.jar
install -m 644 client/target/xmlrpc-client-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/xmlrpc-client-%{version}.jar
install -m 644 server/target/xmlrpc-server-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/xmlrpc-server-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir}/%{name} && for jar in *-%{version}*; do ln -s ${jar} ${jar/-%{version}/}; done)
(cd $RPM_BUILD_ROOT%{_javadir}/ && for jar in *-%{version}*; do ln -s ${jar} ${jar/-%{version}/}; done)

%add_to_maven_depmap org.apache.xmlrpc xmlrpc %{version} JPP %{name}
%add_to_maven_depmap org.apache.xmlrpc xmlrpc-client %{version} JPP/%{name} xmlrpc-client
%add_to_maven_depmap org.apache.xmlrpc xmlrpc-common %{version} JPP/%{name} xmlrpc-common
%add_to_maven_depmap org.apache.xmlrpc xmlrpc-server %{version} JPP/%{name} xmlrpc-server

# poms
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms
install -m 644 pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}.pom
install -m 644 client/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-xmlrpc-client.pom
install -m 644 common/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-xmlrpc-common.pom
install -m 644 server/pom.xml $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-xmlrpc-server.pom

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
%if %with maven
cp -pr target/site/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
%else
for m in common client server; do
    install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}/$m
    cp -pr $m/target/site/apidocs/* \
                      $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}/$m
done
%endif
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

install -d -m 755 $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
%if %with maven
cp -pr target/site/* $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
rm -r $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/apidocs
ln -s %{_javadocdir}/%{name} $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/apidocs
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%doc LICENSE.txt
%dir %{_javadir}*/%{name}
%exclude %dir %{_javadocdir}/%{name}
%{_javadir}*/xmlrpc-%{version}.jar
%{_javadir}*/%{name}/xmlrpc-client-%{version}.jar
%{_javadir}*/%{name}/xmlrpc-client.jar
%{_javadir}*/%{name}/xmlrpc-common-%{version}.jar
%{_javadir}*/%{name}/xmlrpc-common.jar
%{_javadir}*/%{name}/xmlrpc-server-%{version}.jar
%{_javadir}*/%{name}/xmlrpc-server.jar
%{_javadir}*/xmlrpc.jar
%{_datadir}/maven2/poms/JPP-xmlrpc.pom
%{_datadir}/maven2/poms/JPP.xmlrpc-xmlrpc-client.pom
%{_datadir}/maven2/poms/JPP.xmlrpc-xmlrpc-common.pom
%{_datadir}/maven2/poms/JPP.xmlrpc-xmlrpc-server.pom
%{_mavendepmapfragdir}/%{name}

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%if %with maven
%files manual
%defattr(0644,root,root,0755)
%{_docdir}/%{name}-%{version}
%endif

%changelog
* Thu Jul 17 2014 Ralph Apel <r.apel@r-apel.de> 0:3.1.3-5
- fix pom namings

* Tue Jun 14 2011 David Walluck <walluck@redhat.com> 0:3.1.3-4
- fix build

* Wed Dec 22 2010 Ralph Apel <r.apel@r-apel.de> 0:3.1.3-3
- Drop (B)R ws-jaxme

* Wed Dec 22 2010 Ralph Apel <r.apel@r-apel.de> 0:3.1.3-2
- Drop (B)R ws-commons-java5?

* Wed Dec 22 2010 Ralph Apel <r.apel@r-apel.de> 0:3.1.3-1
- 3.1.3
- Build with maven by default

* Tue Nov 11 2008 David Walluck <walluck@redhat.com> 0:3.1-1
- 3.1

* Mon Aug 06 2007 Ralph Apel <r.apel at r-apel.de> - 0:3.0-1jpp
- Upgrade to 3.0
- Add poms and depmap frags
- Make Vendor, Distribution based on macro

* Fri Aug 04 2006 Vivek Lakshmanan <vivekl@redhat.com> - 0:2.0.1-3jpp
- Add conditional native compilation for GCJ.
- Add Requires(x) sections for -javadoc sub-package.

* Mon Apr 04 2006 Ralph Apel <r.apel@r-apel.de> - 0:2.0.1-2jpp
- Fix jakarta-commons requires naming

* Wed Jan 18 2006 Igor Foox <ifoox@rehdat.com> - 0:2.0.1-1jpp
- Update to version 2.0.1.

* Thu Jan 05 2006 Fernando Nasser <fnasser@redhat.com> 0:1.2-0.b1.4jpp
- First JPP 1.7 build

* Thu Aug 26 2004 Ralph Apel <r.apel at r-apel.de> 0:1.2-0.b1.3jpp
- Build with ant-1.6.2

* Thu Apr 29 2004 David Walluck <david@jpackage.org> 0:1.2-0.b1.2jpp
- add jar symlinks
- remove %%buildroot in %%install

* Tue May 06 2003 David Walluck <david@anti-microsoft.org> 0:1.2-0.b1.1jpp
- 1.2-b1
- update for JPackage 1.5

* Mon Mar 18 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.1-1jpp 
- 1.1
- generic servlet support
- used source release
- dropped patch
- added applet jar

* Mon Jan 21 2002 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.0-3jpp 
- versioned dir for javadoc
- no dependencies for javadoc package
- dropped jsse package
- adaptation to new servlet3 package
- adaptation to new jsse package
- section macro

* Fri Dec 7 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.0-2jpp
- javadoc into javadoc package

* Sat Nov 3 2001 Guillaume Rousse <guillomovitch@users.sourceforge.net> 1.0-1jpp
- first JPackage release
